==> haskell-stmonadtrans-0.4.3-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.4.3
id: STMonadTrans-0.4.3-EwuLRjXHjqhA7PmvwSfVjr
key: STMonadTrans-0.4.3-EwuLRjXHjqhA7PmvwSfVjr
license: BSD-3-Clause
maintainer: josef.svenningsson@gmail.com
author: Josef Svenningsson
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.
category: Monads
abi: 7ae231030e254791f8e6dbdd0554bd51
exposed: True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/STMonadTrans-0.4.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/STMonadTrans-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/STMonadTrans-0.4.3
hs-libraries: HSSTMonadTrans-0.4.3-EwuLRjXHjqhA7PmvwSfVjr
depends:
    base-4.11.1.0 mtl-2.2.2 array-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stmonadtrans-0.4.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.4.3
id: STMonadTrans-0.4.3-5W1vTLL9TXlHhtBUYhG71U
key: STMonadTrans-0.4.3-5W1vTLL9TXlHhtBUYhG71U
license: BSD-3-Clause
maintainer: josef.svenningsson@gmail.com
author: Josef Svenningsson
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.
category: Monads
abi: e20716627f7676d725ad44eafc12f82c
exposed: True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/STMonadTrans-0.4.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/STMonadTrans-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/STMonadTrans-0.4.3
hs-libraries: HSSTMonadTrans-0.4.3-5W1vTLL9TXlHhtBUYhG71U
depends:
    array-0.5.2.0 base-4.12.0.0 mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
